@@ -1,28 +1,33 @@
-r"""UUID draft version objects (universally unique identifiers).
+r"""UUID objects (universally unique identifiers) according to RFC 9562.
+
 This module provides the functions uuid6(), uuid7(), and uuid8() for
-generating version 6, 7, and 8 UUIDs as specified in
-https://github.com/ietf-wg-uuidrev/rfc4122bis
+generating version 6, 7, and 8 UUIDs as specified in RFC 9562.
 """
 
+import importlib.metadata
 import secrets
 import time
 import uuid
-from typing import Tuple
+from typing import Optional, Tuple
+
+__version__ = importlib.metadata.version(__package__)
 
 
 class UUID(uuid.UUID):
-    r"""UUID draft version objects"""
+    r"""Instances of the UUID class represent UUIDs as specified in RFC 9562."""
+
+    __slots__ = ()
 
     def __init__(
         self,
-        hex: str = None,
-        bytes: bytes = None,
-        bytes_le: bytes = None,
-        fields: Tuple[int, int, int, int, int, int] = None,
-        int: int = None,
-        version: int = None,
+        hex: Optional[str] = None,
+        bytes: Optional[bytes] = None,
+        bytes_le: Optional[bytes] = None,
+        fields: Optional[Tuple[int, int, int, int, int, int]] = None,
+        int: Optional[int] = None,
+        version: Optional[int] = None,
         *,
-        is_safe=uuid.SafeUUID.unknown
+        is_safe: uuid.SafeUUID = uuid.SafeUUID.unknown,
     ) -> None:
         r"""Create a UUID."""
 
@@ -76,17 +81,28 @@ def _subsec_encode(value: int) -> int:
     return value * 2**20 // 10**6
 
 
+def uuid1_to_uuid6(uuid1: uuid.UUID) -> UUID:
+    r"""Generate a UUID version 6 object from a UUID version 1 object."""
+    if uuid1.version != 1:
+        raise ValueError("given UUID's version number must be 1")
+    h = uuid1.hex
+    h = h[13:16] + h[8:12] + h[0:5] + "6" + h[5:8] + h[16:]
+    return UUID(hex=h, is_safe=uuid1.is_safe)
+
+
 _last_v6_timestamp = None
 _last_v7_timestamp = None
 _last_v8_timestamp = None
 
 
-def uuid6(clock_seq: int = None) -> UUID:
+def uuid6(node: Optional[int] = None, clock_seq: Optional[int] = None) -> UUID:
     r"""UUID version 6 is a field-compatible version of UUIDv1, reordered for
     improved DB locality. It is expected that UUIDv6 will primarily be
     used in contexts where there are existing v1 UUIDs. Systems that do
     not involve legacy UUIDv1 SHOULD consider using UUIDv7 instead.
 
+    If 'node' is not given, a random 48-bit number is chosen.
+
     If 'clock_seq' is given, it is used as the sequence number;
     otherwise a random 14-bit sequence number is chosen."""
 
@@ -101,21 +117,23 @@ def uuid6(clock_seq: int = None) -> UUID:
     _last_v6_timestamp = timestamp
     if clock_seq is None:
         clock_seq = secrets.randbits(14)  # instead of stable storage
+    if node is None:
+        node = secrets.randbits(48)
     time_high_and_time_mid = (timestamp >> 12) & 0xFFFFFFFFFFFF
     time_low_and_version = timestamp & 0x0FFF
     uuid_int = time_high_and_time_mid << 80
     uuid_int |= time_low_and_version << 64
     uuid_int |= (clock_seq & 0x3FFF) << 48
-    uuid_int |= secrets.randbits(48)
+    uuid_int |= node & 0xFFFFFFFFFFFF
     return UUID(int=uuid_int, version=6)
 
 
 def uuid7() -> UUID:
     r"""UUID version 7 features a time-ordered value field derived from the
     widely implemented and well known Unix Epoch timestamp source, the
-    number of milliseconds seconds since midnight 1 Jan 1970 UTC, leap
-    seconds excluded. As well as improved entropy characteristics over
-    versions 1 or 6.
+    number of milliseconds since midnight 1 Jan 1970 UTC, leap seconds
+    excluded. As well as improved entropy characteristics over versions
+    1 or 6.
 
     Implementations SHOULD utilize UUID version 7 over UUID version 1 and
     6 if possible."""
@@ -123,7 +141,7 @@ def uuid7() -> UUID:
     global _last_v7_timestamp
 
     nanoseconds = time.time_ns()
-    timestamp_ms, _ = divmod(nanoseconds, 10**6)
+    timestamp_ms = nanoseconds // 10**6
     if _last_v7_timestamp is not None and timestamp_ms <= _last_v7_timestamp:
         timestamp_ms = _last_v7_timestamp + 1
     _last_v7_timestamp = timestamp_ms
@@ -135,8 +153,8 @@ def uuid7() -> UUID:
 def uuid8() -> UUID:
     r"""UUID version 8 features a time-ordered value field derived from the
     widely implemented and well known Unix Epoch timestamp source, the
-    number of nanoseconds seconds since midnight 1 Jan 1970 UTC, leap
-    seconds excluded."""
+    number of nanoseconds since midnight 1 Jan 1970 UTC, leap seconds
+    excluded."""
 
     global _last_v8_timestamp
 
